import { Project, ProjectProps } from 'aws-cdk-lib/aws-codebuild';
import { Construct } from 'constructs';
export interface SingletonProjectProps extends ProjectProps {
    /**
     * A unique identifier to identify this CodeBuild project.
     *
     * The identifier should be unique across all singleton projects. We recommend generating a UUID per project.
     */
    readonly uuid: string;
    /**
     * A descriptive name for the purpose of this CodeBuild project.
     *
     * If the project does not have a physical name, this string will be reflected its generated name. The combination of projectPurpose and uuid must be unique.
     *
     * @default SingletonProject
     */
    readonly projectPurpose?: string;
}
/**
 * A CodeBuild project that is created only once per stack.
 */
export declare class SingletonProject extends Construct {
    readonly project: Project;
    constructor(scope: Construct, id: string, props: SingletonProjectProps);
    private ensureProject;
    private propsToAdditionalString;
    private slugify;
}
